<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       ht
 * @since      1.0.0
 *
 * @package    Raise_Prices_With_Time_For_Woocommmerce
 * @subpackage Raise_Prices_With_Time_For_Woocommmerce/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Raise_Prices_With_Time_For_Woocommmerce
 * @subpackage Raise_Prices_With_Time_For_Woocommmerce/admin
 * @author     Igor Benić <i.benic@hotmail.com>
 */
class Raise_Prices_With_Time_For_Woocommmerce_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles( $hook ) {

		if( ! $this->is_product_screen( $hook ) ) {
			return;
		}

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Raise_Prices_With_Time_For_Woocommmerce_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Raise_Prices_With_Time_For_Woocommmerce_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/rpt-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts( $hook ) {

		if( ! $this->is_product_screen( $hook ) ) {
			return;
		}
		

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Rps_wc_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Rps_wc_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		wp_enqueue_script('jquery-ui-datepicker');
		 
		wp_register_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/rpt-admin.js', array( 'jquery' ), $this->version, true );
		
		wp_enqueue_script(  $this->plugin_name );
	}

	private function is_product_screen( $hook ) {
		// We want our script to be loaded only on edit or new post
	 	if( 'post.php' !== $hook && 'post-new.php' !== $hook ) {
	 		return false;
	 	}

		global $post;
	 	
	 	if( ! $post ) {
	 		return false;
	 	}

	 	// We want our script to be loaded only on a product type post
	 	if( 'product' != $post->post_type ) {
	 		return false;
	 	}

	 	return true;
	}

	/**
	 * Template for Prices
	 * @return void 
	 */
	public function wc_product_prices() {
		 
		include_once 'partials/rpt-admin-prices.php';
	}

	/**
	 * Saving the Product Prices Data
	 * @param  int $post_id 
	 * @param  WP_Post $post    
	 * @return void          
	 */
	public function wc_product_save( $post_id, $post ) {

		$rpt_array = array();
		$rpt_timestamps = RPT_WC_Meta::get( $post_id, '_rpt_timestamps' );

		if( ! is_array( $rpt_timestamps ) ) {
			$rpt_timestamps = array();
		}
		
		$offset = get_option('gmt_offset') * 3600;

		$count = 0;

		if( isset( $_POST['rpt_wc'] ) ) {

			 
			foreach ( $_POST['rpt_wc'] as $sale_points ) {

				if( ! $sale_points['date'] ) {
					continue;
				}
 
				$rpt_array[ $sale_points['date'] ] = $sale_points['price'];
				$date = new DateTime( $sale_points['date'] );

				$timestamp = $date->getTimestamp();

				if( isset( $rpt_timestamps[ $count ] ) && $rpt_timestamps[ $count ] != $timestamp ) {
					// We have something else, remove the previous timestamp
					wp_unschedule_event( $rpt_timestamps[ $count ] - $offset, 'rpt_wc_increase_price', array( $post_id, $sale_points['price'] ) );
				}

				// Let's unschedule it first just in case
				wp_unschedule_event( $timestamp - $offset, 'rpt_wc_increase_price', array( $post_id, $sale_points['price'] ) );
				
				wp_schedule_single_event( $timestamp - $offset, 'rpt_wc_increase_price', array( $post_id, $sale_points['price'] ) );
				
				$rpt_timestamps[ $count ] = $timestamp;
				$count++;
			}
		}

		// We have more saved then posted
		if( count( $rpt_timestamps ) > $count ) {
			$prices = RPT_WC_Meta::get( $post_id );
			for ( $i = $count; $i < count( $rpt_timestamps ); $i++ ) { 
				$date_time = new DateTime();

				$date_time->setTimestamp( $rpt_timestamps[ $i ] );

				$formatted_date = $date_time->format( 'd-m-Y' );

				// Unschedule it
				if( isset( $prices[ $formatted_date ] ) ) {
					wp_unschedule_event( $rpt_timestamps[ $i ] - $offset, 'rpt_wc_increase_price', array( $post_id, $prices[ $formatted_date ] ) );
				}
				unset( $rpt_timestamps[ $count ] );
			}
		}


		if( $rpt_array ) {

			// Let's sort from first to last
			sort( $rpt_timestamps );

			RPT_WC_Meta::update( $post_id, $rpt_array );
			RPT_WC_Meta::update( $post_id, $rpt_timestamps, '_rpt_timestamps' );
		}
		 
	}

}
