<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       ht
 * @since      1.0.0
 *
 * @package    Raise_Prices_With_Time_For_Woocommmerce
 * @subpackage Raise_Prices_With_Time_For_Woocommmerce/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Raise_Prices_With_Time_For_Woocommmerce
 * @subpackage Raise_Prices_With_Time_For_Woocommmerce/public
 * @author     Igor Benić <i.benic@hotmail.com>
 */
class Raise_Prices_With_Time_For_Woocommmerce_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Raise_Prices_With_Time_For_Woocommmerce_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Raise_Prices_With_Time_For_Woocommmerce_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		
		if( ! is_singular( 'product' ) ) {
			return;
		}

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/rpt-wc-public.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Raise_Prices_With_Time_For_Woocommmerce_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Raise_Prices_With_Time_For_Woocommmerce_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		
		if( ! is_singular( 'product' ) ) {
			return;
		}

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/rpt-wc-public.js', array( 'jquery' ), $this->version, false );

	}

	/**
	 * The method that will be called on the CRON 
	 * @param  int $product_id 
	 * @param  int $price      
	 * @return void             
	 */
	public function rpt_increase_price_cron( $product_id, $price ) {
		$product = wc_get_product( $product_id );
		
		if( $product ) {
			$product->set_regular_price( $price );
			$product->save();
		}
	}

	/**
	 * Show the Countdown
	 * @return void 
	 */
	public function show_product_countdown() {
		global $product;

		$product_id = $product->get_id();
		$rps_prices = RPT_WC_Meta::get( $product_id );
		$rpt_timestamps = RPT_WC_Meta::get( $product_id, '_rpt_timestamps' );

		$now = time();
		$found_new_timestamp = false;
		foreach ( $rpt_timestamps as $timestamp ) {
			// We have a timestamp from future
			if( $now < $timestamp ) {
				$found_new_timestamp = $timestamp;
				break;
			}
		}
		 
		if( $found_new_timestamp ) {
			$offset = get_option('gmt_offset') * 3600;
			$timestamp_with_offset = $found_new_timestamp - $offset;
			echo '<div class="rpt-countdown-container">';
				$show_only_countdown = apply_filters( 'rpt_wc_show_only_countdown', false );
				if( ! $show_only_countdown ) {
					echo '<p>' . __( 'The price will change in:', 'rpt-wc' ) . '</p>';
				}
				echo '<div class="rpt-countdown" data-timestamp="' . $timestamp_with_offset . '"></div>';
			echo '</div>';
		}
	}

}
